""" A {{ class }} Module """


class {{ class }}:
    """Class Docstring Description
    """

    def show(self):
        """Show several resource listings
        """

        pass

    def index(self):
        """Show a single resource listing
        """

        pass

    def create(self):
        """Show form to create new resource listings
        """

        pass

    def store(self):
        """Create a new resource listing
        """

        pass

    def edit(self):
        """Show form to edit an existing resource listing
        """

        pass

    def update(self):
        """Edit an existing resource listing
        """

        pass

    def destroy(self):
        """Delete an existing resource listing
        """

        pass
