{% extends 'auth/base.html' %}

{% block content %}
<div class="row my-5">
    <div class="col-md-12">
        <div class="row">
            <div class="col-md-6 mx-auto">
                <div class="card rounded-1">
                    <div class="card-header">
                        <h5 class="mb-0">Login</h5>
                    </div>
                    <div class="card-body">
                        <form class="form" action="/login" method="POST">
                            {{ csrf_field }}
                            <div class="form-group">
                                <label for="">Email</label>
                                <input type="text" class="form-control form-control-md rounded-0" name="email">
                            </div>
                            <div class="form-group">
                                <label>Password</label>
                                <input type="password" class="form-control form-control-md rounded-0" name="password">
                            </div>
                            <button type="submit" class="btn btn-success btn-md float-right">Login</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}
